@@ -422,8 +422,11 @@ static void recurse_directories_internal(gchar *name, GSList **trknames, gboolea
 
                     if (g_hash_table_lookup(*directories_seen, nextfull))
                         continue;
-                    else
-                        g_hash_table_insert(*directories_seen, nextfull, nextfull);
+                    else {
+                        // Avoid double freeing when directories_seen is destroyed
+                        // by duplicating the nextfull string
+                        g_hash_table_insert(*directories_seen, g_strdup(nextfull), g_strdup(nextfull));
+                    }
 
                     if (descend || !g_file_test(nextfull, G_FILE_TEST_IS_DIR)) {
                         recurse_directories_internal(nextfull, trknames, descend, directories_seen);
@@ -1180,7 +1183,7 @@ Track *get_track_info_from_file(gchar *name, Track *orig_track, GError **error)
 
     GError *info_error = NULL;
     nti = filetype_get_file_info(filetype, name, &info_error);
-    if (info_error || !nti) {
+    if (info_error && !nti) {
         gtkpod_log_error_printf(error, _("No track information could be retrieved from the file %s due to the following error:\n\n%s"), name_utf8, info_error->message);
         g_error_free(info_error);
         info_error = NULL;
