@@ -71,7 +71,7 @@ static gboolean
 dnd_coverart_drag_motion(GtkWidget *widget, GdkDragContext *dc, gint x, gint y, guint time, gpointer user_data);
 
 static void set_cover_dimensions(Cover_Item *cover, int cover_index, gdouble img_width, gdouble img_height);
-static void coverart_sort_images(GtkSortType order);
+static void coverart_sort_images(enum GtkPodSortTypes order);
 static void set_slider_range(gint index);
 static GdkRGBA *convert_hexstring_to_rgba(const gchar *hexstring);
 static gboolean on_drawing_area_drawn(GtkWidget *draw_area, cairo_t *cairo_draw_context, gpointer data);
@@ -174,7 +174,7 @@ void coverart_init_display(GtkWidget *parent, gchar *gladepath) {
     cdwidget->controlbox = gtkpod_builder_xml_get_widget(xml, "cover_display_controlbox");
     cdwidget->leftbutton = GTK_BUTTON (gtkpod_builder_xml_get_widget (xml, "cover_display_leftbutton"));
     cdwidget->rightbutton = GTK_BUTTON (gtkpod_builder_xml_get_widget (xml, "cover_display_rightbutton"));
-    cdwidget->cdslider = GTK_HSCALE (gtkpod_builder_xml_get_widget (xml, "cover_display_scaler"));
+    cdwidget->cdslider = GTK_SCALE (gtkpod_builder_xml_get_widget (xml, "cover_display_scaler"));
     /* create a new drawing area */
     cdwidget->draw_area = gtk_drawing_area_new();
     cdwidget->cdcovers = g_ptr_array_sized_new(IMG_TOTAL);
@@ -398,8 +398,11 @@ static void draw(cairo_t *cairo_context) {
         cover->album = album;
 
         if (force_pixbuf_covers) {
-            g_object_unref(album->albumart);
-            album->albumart = NULL;
+            if (album->albumart) {
+                g_object_unref(album->albumart);
+                album->albumart = NULL;
+            }
+
             if (album->scaled_art != NULL) {
                 g_object_unref(album->scaled_art);
                 album->scaled_art = NULL;
@@ -600,7 +603,7 @@ void coverart_display_update(gboolean clear_track_list) {
 void coverart_display_sort(gint order) {
     prefs_set_int("cad_sort", order);
     coverart_display_update(TRUE);
-    gtkpod_broadcast_preference_change("cad_sort", order);
+    gtkpod_broadcast_preference_change("cad_sort", &order);
 }
 
 /**
@@ -946,8 +949,7 @@ void coverart_track_changed(Track *track, gint signal) {
                 /* Track exists in the album list so ignore the change and return */
                 ExtraTrackData *etd;
                 etd = track->userdata;
-                if (etd->tartwork_changed == TRUE) {
-                    etd->tartwork_changed = FALSE;
+                if (etd->tartwork_changed) {
                     redraw(TRUE);
                 }
 
@@ -1563,7 +1565,7 @@ static gint compare_album_keys(gchar *a, gchar *b) {
  * @order: order type
  *
  */
-static void coverart_sort_images(GtkSortType order) {
+static void coverart_sort_images(enum GtkPodSortTypes order) {
     if (order == SORT_NONE) {
         /* No sorting means original order so this should have been called after a coverart_display_update (TRUE)
          * when the TRUE means the tracks were freshly established from the playlist and the hash and key_list
@@ -1575,7 +1577,7 @@ static void coverart_sort_images(GtkSortType order) {
         album_key_list = g_list_sort(album_key_list, (GCompareFunc) compare_album_keys);
     }
 
-    if (order == GTK_SORT_DESCENDING) {
+    if (order == SORT_DESCENDING) {
         album_key_list = g_list_reverse(album_key_list);
     }
 }
